==> apache-log4net-source-2.0.17.zip: apache-log4net-source-2.0.17/src/log4net.Tests/Appender/AdoNet/Log4NetParameterCollection.cs <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
*/

using System;
using System.Collections;
using System.Data;

namespace log4net.Tests.Appender.AdoNet
{
  public class Log4NetParameterCollection : CollectionBase, IDataParameterCollection
  {
    #region AdoNetAppender

    private readonly Hashtable parameterNameToIndex = new Hashtable();

    protected override void OnInsertComplete(int index, object value)
    {
      base.OnInsertComplete(index, value);

      IDataParameter param = (IDataParameter)value;
      parameterNameToIndex[param.ParameterName] = index;
    }

    public int IndexOf(string parameterName)
    {
      return (int)parameterNameToIndex[parameterName];
    }

    public object this[string parameterName]
    {
      get { return InnerList[IndexOf(parameterName)]; }
      set { InnerList[IndexOf(parameterName)] = value; }
    }

    #endregion

    #region Not Implemented

    public void RemoveAt(string parameterName)
    {
      throw new NotImplementedException();
    }

    public bool Contains(string parameterName)
    {
      throw new NotImplementedException();
    }

    #endregion
  }
}

==> apache-log4net-source-3.0.0.zip: apache-log4net-source-3.0.0/src/log4net.Tests/Appender/AdoNet/Log4NetParameterCollection.cs <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
*/

using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;

namespace log4net.Tests.Appender.AdoNet
{
  public class Log4NetParameterCollection : CollectionBase, IDataParameterCollection
  {
    private readonly Dictionary<string, int> m_parameterNameToIndex = new(StringComparer.Ordinal);

    protected override void OnInsertComplete(int index, object? value)
    {
      base.OnInsertComplete(index, value);

      if (value is IDataParameter param)
      {
        m_parameterNameToIndex[param.ParameterName] = index;
      }
    }

    public int IndexOf(string parameterName)
    {
      if (m_parameterNameToIndex.TryGetValue(parameterName, out var index))
      {
        return index;
      }
      return -1;
    }

    public object this[string parameterName]
    {
      get => InnerList[IndexOf(parameterName)]!;
      set => InnerList[IndexOf(parameterName)] = value;
    }

    public void RemoveAt(string parameterName)
    {
      throw new NotImplementedException();
    }

    public bool Contains(string parameterName)
    {
      throw new NotImplementedException();
    }
  }
}
